aboutsummaryrefslogtreecommitdiff
path: root/libbuild2/build/script/script.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'libbuild2/build/script/script.hxx')
-rw-r--r--libbuild2/build/script/script.hxx6
1 files changed, 4 insertions, 2 deletions
diff --git a/libbuild2/build/script/script.hxx b/libbuild2/build/script/script.hxx
index de759de..5fd8561 100644
--- a/libbuild2/build/script/script.hxx
+++ b/libbuild2/build/script/script.hxx
@@ -58,9 +58,11 @@ namespace build2
//
bool temp_dir = false;
// Command name for low-verbosity diagnostics.
//
- optional<string> diag;
+ optional<string> diag_name;
+ optional<line> diag_line;
location start_loc;
location end_loc;
@@ -58,9 +58,11 @@ namespace build2
//
bool temp_dir = false;
- // Command name for low-verbosity diagnostics.
+ // Command name for low-verbosity diagnostics and custom low-verbosity
+ // diagnostics line. Note: cannot be both.
//